@@ -107,3 +107,36 @@ class Namespace():
     ### Defines empty namespace ###
     def __init__(self, **kwargs):
         self.__dict__.update(kwargs)
+
+def timer():
+    from datetime import datetime
+    def dec_outer(fn):
+        @wraps(fn)
+        def dec_inner(*args, **kwargs):
+            st = datetime.utcnow().timestamp()
+            response = fn(*args, **kwargs)
+            print(f'{fn.__name__} ran in {f2(datetime.utcnow().timestamp() - st)} seconds')
+            return response
+        return dec_inner
+    return dec_outer
+
+
+def cache(reload=True):
+    from functools import wraps
+    def dec_outer(fn):
+        @wraps(fn)
+        def dec_inner(*args, **kwargs):
+            if reload:
+                response = fn(*args, **kwargs)
+                to_pickle(response, 'cache.pkl')
+            else:
+                import os.path
+                if os.path.isfile('cache.pkl'):
+                    response = from_pickle('cache.pkl')
+                else:
+                    response = fn(*args, **kwargs)
+                    to_pickle(response, 'cache.pkl')
+            return response
+        return dec_inner
+    return dec_outer
+
